Learn R Programming

cosinor2 (version 0.2.1)

cosinor.PR: Percent Rhythm

Description

Calculates Percent Rhythm, the measure of the relative strength of a rhythm.

Usage

cosinor.PR(x)

Arguments

x

An object of the cosinor.lm or population.cosinor.lm class.

Details

Percent Rhythm is the coefficient of determination obtained by squaring the correlation between observed and estimated values.

Examples

Run this code
# NOT RUN {
fit.temperature<-cosinor.lm(Temperature~time(Time), period = 24, data = temperature_zg)
cosinor.PR(fit.temperature)

fit.november<-population.cosinor.lm(data = PANAS_november, time = PANAS_time,
period = 7)
cosinor.PR(fit.november)
# }

Run the code above in your browser using DataLab