Learn R Programming

cosinor2 (version 0.2.1)

temperature_zg: Daily air temperature in Zagreb

Description

A dataset containing the air temperature in Zagreb on July 1, 2015.

Usage

temperature_zg

Arguments

Format

A data frame with two variables:

Temperature

Air temperature in Zagreb on July 1, 2015.

Time

Time of the day when the temperature was measured.

Details

Measurements were taken every 30 minutes throughout the whole day.