Runs the tests that compare MESORs, amplitudes and acrophases of two different populations.
cosinor.poptests(pop1, pop2)An object of the population.cosinor.lm class calculated on the first population.
An object of the population.cosinor.lm class calculated on the second population.
Bingham et al. (1982) describe tests for comparing population MESORs, amplitudes and acrophases. These tests are esentially F-ratios with \(df_1 = m - 1\) and \(df_2 = K - m\), where \(m\) is the number of populations and \(K\) is the total number of subjects. The tests for MESOR, amplitude and acrophase differences respectively are calculated as follows: $$F_M = \frac{\sum_{j = 1}^{m}k_j(\widehat{M}_j - \widehat{M})^2}{(m-1)\widehat{\sigma}_M^2}$$ $$F_\phi = \frac{\frac{\sum_{j = 1}^{m}k_j A_j^2 * sin^2(\widehat{\phi}_j - \tilde{\phi})}{m - 1}} {\widehat{\sigma}_\beta^2 sin^2\tilde{\phi} + 2\widehat{\sigma}_{\beta \gamma} cos\tilde{\phi}sin\tilde{\phi} + \widehat{\sigma}_\gamma^2 cos^2\tilde{\phi}}$$ $$F_A = \frac{\frac{\sum_{j = 1}^{m}(\widehat{A}_j - \widehat{A})^2}{m - 1}}{\widehat{\sigma}^2_\beta cos^2\widehat{\phi} - 2\widehat{\sigma}_{\beta \gamma}cos\widehat{\phi}sin\widehat{\phi} + \widehat{\sigma}^2_\gamma sin^2 \widehat{\phi}}$$ where \(\widehat{M}\), \(\widehat{A}\) and \(\widehat{\phi}\) are weighted averages of parameters across populations calculated as: $$\widehat{M} = \frac{\sum_{j = 1}^{m}k_j\widehat{M}_j}{K}$$ $$\widehat{A} = \frac{\sum_{j = 1}^{m}k_j\widehat{A}_j}{K}$$ $$\widehat{\phi} = \frac{\sum_{j = 1}^{m}k_j\widehat{\phi}_j}{K}$$ \(\tilde{\phi}\) is derived from the following expression: $$tan 2\tilde{\phi} = \frac{\sum_{j = 1}^{m}k_j\widehat{A}^2_j sin 2\widehat{\phi}_j}{\sum_{j = 1}^{m}k_j\widehat{A}^2_j cos 2\widehat{\phi}_j}$$ where \(2\tilde{\phi}\) lies between \(-\frac{\pi}{2}\) and \(\frac{\pi}{2}\) if the denomanator is positive or between \(\frac{\pi}{2}\) and \(\frac{3\pi}{2}\) if the denominator is negative, \(k_j\) is the number of subjects in the \(j\)th population, \(\widehat{M}_j\), \(\widehat{A}_j\) and \(\widehat{\phi}_j\) are the cosinor parameters of the \(j\)th population and \(\widehat{\sigma}_\beta\),\(\widehat{\sigma}_\gamma\) and \(\widehat{\sigma}_{\beta \gamma}\) are the estimates of pooled standard deviations (and covariance) calculated as following: $$\widehat{\sigma}_\beta = \frac{\sum_{j = 1}^{m} (k_j - 1)\widehat{\sigma}_{\beta_j}}{K - m}$$ $$\widehat{\sigma}_\gamma = \frac{\sum_{j = 1}^{m} (k_j - 1)\widehat{\sigma}_{\gamma_j}}{K - m}$$ $$\widehat{\sigma}_{\beta \gamma} = \frac{\sum_{j = 1}^{m} (k_j - 1)\widehat{\sigma}_{{\beta_j} {\gamma_j}}}{K - m}$$ where \(\widehat{\sigma}_{\beta_j}\), \(\widehat{\sigma}_{\gamma_j}\) and \(\widehat{\sigma}_{{\beta_j} {\gamma_j}}\) are the standard devations and covariance of \(\beta\) and \(\gamma\) parameters in the \(j\)th population.
Bingham, C., Arbogast, B., Guillaume Corn<U+00E9>lissen, G., Lee, J.K. & Halberg, F. (1982). Inferential Statistical Methods for Estimating and Comparing Cosinor Parameters. Chronobiologia, 9(4), 397-439.
# NOT RUN {
fit.extraverts<-population.cosinor.lm(data = PA_extraverts, time = PA_time,
period = 24)
fit.introverts<-population.cosinor.lm(data = PA_introverts, time = PA_time,
period = 24)
cosinor.poptests(pop1 = fit.extraverts, pop2 = fit.introverts)
# }
Run the code above in your browser using DataLab